package examples.jce.session;

import java.io.*;
import java.net.*;
import java.util.*;

import javax.crypto.*;
import java.security.*;
import java.security.spec.*;
import java.security.cert.*;

import javax.crypto.spec.*;

/**
 * Wrapper class to run Session example.
 * <p>
 * Both sides of the session are managed by 'ClientSide' and 'ServerSide'
 * classes. A Secure random number generator is created and handed to the
 * managers along a keystore and the key store password. This saves the
 * examples having to generate the key pairs at run time and it also 
 * demonstrates the necessary difference between having a key pair for
 * encryption and decryption use only as well as another key pair for
 * signing use only.
 */
public class BasicRSASession
{
    private static KeyStore key_store = null;
    private static char[] ks_pass = null;

    private static int port = 1887;
    private static SecureRandom sec_rand = null;

    public static void main(String[] args)
    {
        Security.addProvider(new org.bouncycastle.jce.provider.BouncyCastleProvider());

        try
        {
            sec_rand = SecureRandom.getInstance("SHA1PRNG","SUN"); // Set up random number generator.
            key_store = KeyStore.getInstance("JKS","SUN"); // Get a key store instance.
            ks_pass = "foobar".toCharArray(); // Password for example key store.
            key_store.load(new FileInputStream("keys/session.str"),ks_pass); // Load key store.    	    

	        //
	        // Seed random number generator.
	        // This should work on most UNIX boxes quite well.
	        // Windows users will have to wait for SecureRandom to self
            // seed the first time it is called.
            //

            if (new File("/dev/urandom").exists())
            {
                System.out.println("Salting SecureRandom (SHA1PRNG) from /dev/urandom");
                byte[] salt = new byte[8192];
                new FileInputStream("/dev/urandom").read(salt);
                sec_rand.setSeed(salt);
                for (int t=0; t<salt.length; t++) salt[t] = 0;
                salt = null;
            }

            //
            // Server side manages the servers side of the session
            // establishment.
            //
            ServerSide server_side = new ServerSide(key_store, ks_pass, port, sec_rand);

            //
            // Client side manages the clients side of the session
            // establishment.
            //
            ClientSide client_side = new ClientSide(key_store, ks_pass, port, sec_rand);

            //
            // Start the server process.
            //
            server_side.invokeServer();


            //
            // Start Client side and perform session establishment.
            //
	        client_side.doClientSide();
        }
        catch (Exception ex)
	    {
		    ex.printStackTrace();
	    }
    }
}
